==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Spatial_sorting/group__PkgSpatialSortingFunctionObjects.js <==
var group__PkgSpatialSortingFunctionObjects =
[
    [ "Hilbert_sort_2", "classCGAL_1_1Hilbert__sort__2.html", [
      [ "Hilbert_sort_2", "classCGAL_1_1Hilbert__sort__2.html#acb739d76df0e698f66a206bc5994f10e", null ],
      [ "operator()", "classCGAL_1_1Hilbert__sort__2.html#ac48bbffa74a992774bd41afeabbf0cac", null ]
    ] ],
    [ "Hilbert_sort_3", "classCGAL_1_1Hilbert__sort__3.html", [
      [ "Hilbert_sort_3", "classCGAL_1_1Hilbert__sort__3.html#a23097c9f503d041a715968290a88e827", null ],
      [ "operator()", "classCGAL_1_1Hilbert__sort__3.html#a684bca738136684fbe4c494fb756235c", null ]
    ] ],
    [ "Hilbert_sort_d", "classCGAL_1_1Hilbert__sort__d.html", [
      [ "Hilbert_sort_d", "classCGAL_1_1Hilbert__sort__d.html#a722aee9c22b76741579e0cb0fd2367e5", null ],
      [ "operator()", "classCGAL_1_1Hilbert__sort__d.html#aac8009d8fbeeb8a3baa19a7dd3a1f15e", null ]
    ] ],
    [ "Hilbert_sort_on_sphere_3", "classCGAL_1_1Hilbert__sort__on__sphere__3.html", [
      [ "Hilbert_sort_on_sphere_3", "classCGAL_1_1Hilbert__sort__on__sphere__3.html#a21e98d3e4664b07063d98d69ebf6e5df", null ],
      [ "operator()", "classCGAL_1_1Hilbert__sort__on__sphere__3.html#ae216b87a8f7a936efb4aa93ec4dede4f", null ]
    ] ],
    [ "Multiscale_sort", "classCGAL_1_1Multiscale__sort.html", [
      [ "Multiscale_sort", "classCGAL_1_1Multiscale__sort.html#adabf07b6086367c999b26e3571d2ae55", null ],
      [ "operator()", "classCGAL_1_1Multiscale__sort.html#a68873b6bce2e4ee024b6a7d0a7527ef7", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Spatial_sorting/group__PkgSpatialSortingFunctionObjects.js <==
var group__PkgSpatialSortingFunctionObjects =
[
    [ "CGAL::Hilbert_sort_2< Traits, PolicyTag, ConcurrencyTag >", "classCGAL_1_1Hilbert__sort__2.html", [
      [ "Hilbert_sort_2", "classCGAL_1_1Hilbert__sort__2.html#acb739d76df0e698f66a206bc5994f10e", null ],
      [ "operator()", "classCGAL_1_1Hilbert__sort__2.html#ac48bbffa74a992774bd41afeabbf0cac", null ]
    ] ],
    [ "CGAL::Hilbert_sort_3< Traits, PolicyTag, ConcurrencyTag >", "classCGAL_1_1Hilbert__sort__3.html", [
      [ "Hilbert_sort_3", "classCGAL_1_1Hilbert__sort__3.html#a23097c9f503d041a715968290a88e827", null ],
      [ "operator()", "classCGAL_1_1Hilbert__sort__3.html#a684bca738136684fbe4c494fb756235c", null ]
    ] ],
    [ "CGAL::Hilbert_sort_d< Traits, PolicyTag >", "classCGAL_1_1Hilbert__sort__d.html", [
      [ "Hilbert_sort_d", "classCGAL_1_1Hilbert__sort__d.html#a722aee9c22b76741579e0cb0fd2367e5", null ],
      [ "operator()", "classCGAL_1_1Hilbert__sort__d.html#aac8009d8fbeeb8a3baa19a7dd3a1f15e", null ]
    ] ],
    [ "CGAL::Hilbert_sort_on_sphere_3< Traits, PolicyTag >", "classCGAL_1_1Hilbert__sort__on__sphere__3.html", [
      [ "Hilbert_sort_on_sphere_3", "classCGAL_1_1Hilbert__sort__on__sphere__3.html#a21e98d3e4664b07063d98d69ebf6e5df", null ],
      [ "operator()", "classCGAL_1_1Hilbert__sort__on__sphere__3.html#ae216b87a8f7a936efb4aa93ec4dede4f", null ]
    ] ],
    [ "CGAL::Multiscale_sort< Sort >", "classCGAL_1_1Multiscale__sort.html", [
      [ "Multiscale_sort", "classCGAL_1_1Multiscale__sort.html#adabf07b6086367c999b26e3571d2ae55", null ],
      [ "operator()", "classCGAL_1_1Multiscale__sort.html#a68873b6bce2e4ee024b6a7d0a7527ef7", null ]
    ] ]
];
